@@ -5,16 +5,19 @@ srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
 PKG_NAME="epiphany"
+REQUIRED_AUTOMAKE_VERSION=1.9
 
-(test -f $srcdir/src/ephy-window.c) || {
+(test -f $srcdir/configure.ac \
+  && test -f $srcdir/src/ephy-window.c) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level $PKG_NAME directory"
     exit 1
 }
 
 which gnome-autogen.sh || {
-    echo "You need to install gnome-common from the GNOME CVS"
+    echo "You need to install gnome-common from GNOME CVS and make"
+    echo "sure the gnome-autogen.sh script is in your \$PATH."
     exit 1
 }
 
-USE_COMMON_DOC_BUILD=yes REQUIRED_AUTOMAKE_VERSION=1.8 USE_GNOME2_MACROS=1 . gnome-autogen.sh
+USE_GNOME2_MACROS=1 . gnome-autogen.sh
