@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-cache.c 6785 2007-01-03 08:17:59Z diegoe $
+ *  $Id: ephy-favicon-cache.c,v 1.60 2006/09/13 11:34:13 chpe Exp $
  */
 
 #include "config.h"
@@ -45,7 +45,6 @@
 #define EPHY_FAVICON_CACHE_XML_VERSION (const xmlChar *)"1.1"
 
 #define EPHY_FAVICON_CACHE_OBSOLETE_DAYS 30
-#define SECS_PER_DAY (60*60*24)
 
 /* how often to save the cache, in milliseconds */
 #define CACHE_SAVE_INTERVAL	10 * 60 * 1000 /* ms */
@@ -89,7 +88,7 @@ typedef struct
 	guint load_failed : 1;
 } PixbufCacheEntry;
 
-typedef gboolean (* FilterFunc) (EphyNode*, time_t);
+typedef gboolean (* FilterFunc) (EphyNode*, GDate *);
 
 enum
 {
@@ -188,13 +187,23 @@ pixbuf_cache_entry_free (PixbufCacheEntry *entry)
 }
 
 static gboolean
-icon_is_obsolete (EphyNode *node, time_t now)
+icon_is_obsolete (EphyNode *node, GDate *now)
 {
 	int last_visit;
+	GDate date;
 
 	last_visit = ephy_node_get_property_int
 		(node, EPHY_NODE_FAVICON_PROP_LAST_USED);
-	return now - last_visit >= EPHY_FAVICON_CACHE_OBSOLETE_DAYS*SECS_PER_DAY;
+
+	g_date_clear (&date, 1);
+#if GLIB_CHECK_VERSION (2,9,0)
+        g_date_set_time_t (&date, last_visit);
+#else
+	g_date_set_time (&date, last_visit);
+#endif
+
+	return (g_date_days_between (&date, now) >=
+		EPHY_FAVICON_CACHE_OBSOLETE_DAYS);
 }
 
 static void
@@ -228,9 +237,14 @@ remove_obsolete_icons (EphyFaviconCache *cache,
 	EphyFaviconCachePrivate *priv = cache->priv;
 	GPtrArray *children;
 	int i;
-	time_t now;
+	GDate current_date;
 
-	now = time (NULL);
+	g_date_clear (&current_date, 1);
+#if GLIB_CHECK_VERSION (2,9,0)
+        g_date_set_time_t (&current_date, time (NULL));
+#else
+	g_date_set_time (&current_date, time (NULL));
+#endif
 
 	children = ephy_node_get_children (priv->icons);
 	for (i = (int) children->len - 1; i >= 0; i--)
@@ -239,7 +253,7 @@ remove_obsolete_icons (EphyFaviconCache *cache,
 
 		kid = g_ptr_array_index (children, i);
 
-		if (!filter || filter (kid, now))
+		if (!filter || filter (kid, &current_date))
 		{
 			const char *filename;
 			char *path;
