@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2001 Philip Langdale
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2001 Philip Langdale
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.56 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.59 2006/09/13 11:34:14 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -44,6 +44,7 @@
 #include "ephy-prefs.h"
 
 #include "AutoJSContextStack.h"
+#include "AutoWindowModalState.h"
 #include "EphyUtils.h"
 
 #include "FilePicker.h"
@@ -77,6 +78,8 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 {
 	LOG ("GFilePicker::Init");
 
+	mParent = do_QueryInterface (parent);
+
 	GtkWidget *gtkparent = EphyUtils::FindGtkParent (parent);
 #if defined(MOZ_NSIFILEPICKER_NSASTRING_)
 	NS_ENSURE_TRUE (gtkparent, NS_ERROR_FAILURE);
@@ -431,6 +434,9 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 	rv = stack.Init ();
 	if (NS_FAILED (rv)) return rv;
 
+	AutoWindowModalState (mParent);
+	mParent = nsnull;
+
 	LOG ("GFilePicker::Show");
 
 	gtk_window_set_modal (GTK_WINDOW (mDialog), TRUE);
