@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
- *  Copyright (C) 2004 Peter Harvey
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
+ *  Copyright © 2004 Peter Harvey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-menu.c,v 1.46 2006/01/17 22:56:59 paharvey Exp $
+ *  $Id: ephy-bookmarks-menu.c,v 1.51 2006/09/13 11:34:24 chpe Exp $
  */
 
 #include "config.h"
@@ -37,7 +37,7 @@
 
 #include <string.h>
 
-#define MIN_MENU_SIZE 7
+#define MIN_MENU_SIZE 3
 #define MAX_MENU_SIZE 21
 
 enum
@@ -48,23 +48,24 @@ enum
     BUILD_CHILD_SUBMENUS = 1 << 3
 };
 
-/* Construct a block of bookmark actions, postfixing the names with a topic id
- * to allow different. */
+/* Construct a block of bookmark actions. Note that no bookmark action appears
+ * more than once in a menu, so no need to supply names. */
 static void
-append_bookmarks (GString *string, const GPtrArray *bookmarks, gint instance)
+append_bookmarks (GString *string,
+		  const GPtrArray *bookmarks)
 {
-	char *name;
+	EphyNode *child;
+	char name[EPHY_BOOKMARK_ACTION_NAME_BUFFER_SIZE];
+
 	long i;
 	
 	for (i = 0; i < bookmarks->len; i++)
 	{
-		name = ephy_bookmark_action_name (g_ptr_array_index (bookmarks, i));
-		if (name)
-		{
-			g_string_append_printf (string, "<menuitem action=\"%s\" name=\"%s-%d\"/>",
-						name, name, instance);
-			g_free (name);
-		}
+		child = g_ptr_array_index (bookmarks, i);
+
+		EPHY_BOOKMARK_ACTION_NAME_PRINTF (name, child);
+
+		g_string_append_printf (string, "<menuitem action=\"%s\"/>", name);
 	}
 }
 
@@ -86,7 +87,7 @@ append_menu (GString *string, const GPtrArray *topics, const GPtrArray *bookmark
 		EphyNode *topic;
 		gint size, total;
 		gboolean separate = FALSE;
-		char *name;
+		char name[EPHY_TOPIC_ACTION_NAME_BUFFER_SIZE];
 		
 		/* Get the subtopics, uncovered bookmarks, and subtopic sizes. */
 		sizes = g_array_sized_new (FALSE, FALSE, sizeof(int), topics->len);
@@ -133,17 +134,14 @@ append_menu (GString *string, const GPtrArray *topics, const GPtrArray *bookmark
 		{
 			topic = g_ptr_array_index (submenus, i);
 			ephy_nodes_get_covered (topic, bookmarks, subset);
-			
-			name = ephy_topic_action_name (topic);
-			if (name)
-			{
-				g_string_append_printf (string, "<menu name=\"%s\" action=\"%s\">",
-							name, name);
-				append_menu (string, topics, subset, flags);
-				g_string_append (string, "</menu>");
-				separate = TRUE;
-				g_free (name);
-			}
+
+			EPHY_TOPIC_ACTION_NAME_PRINTF (name, topic);
+				
+			g_string_append_printf (string, "<menu action=\"%s\">",
+						name);
+			append_menu (string, topics, subset, flags);
+			g_string_append (string, "</menu>");
+			separate = TRUE;
 		}
 		
 		/* Build a list of bookmarks which don't appear in any subdivision yet. */
@@ -160,7 +158,7 @@ append_menu (GString *string, const GPtrArray *topics, const GPtrArray *bookmark
 			g_ptr_array_sort (subset, ephy_bookmarks_compare_bookmark_pointers);
 			
 			if (separate) g_string_append (string, "<separator/>");
-			append_bookmarks (string, subset, i+1);
+			append_bookmarks (string, subset);
 			separate = TRUE;
 			
 			/* Record that each bookmark has been added. */
@@ -189,7 +187,7 @@ append_menu (GString *string, const GPtrArray *topics, const GPtrArray *bookmark
 	
 	/* Create the final subdivision (uncovered bookmarks). */
 	g_ptr_array_sort (uncovered, ephy_bookmarks_compare_bookmark_pointers);
-	append_bookmarks (string, uncovered, 0);
+	append_bookmarks (string, uncovered);
 	g_ptr_array_free (uncovered, TRUE);        
 }
 
@@ -252,17 +250,17 @@ ephy_bookmarks_menu_build (GString *string, EphyNode *parent)
 	/* Otherwise, build the menu with "Open in tabs". */
 	else
 	{
-		char *name;
+		char name[EPHY_OPEN_TABS_ACTION_NAME_BUFFER_SIZE];
 
 		append_menu (string, topics, children, flags);
 		g_ptr_array_free (topics, TRUE);
 	
 		if (children->len > 1)
 		{
-			name = ephy_open_tabs_action_name (node);
+			EPHY_OPEN_TABS_ACTION_NAME_PRINTF (name, node);
+
 			g_string_append_printf
-			  (string, "<separator/><menuitem action=\"%s\" name=\"OpenTabs\"/>", name);
-			g_free (name);
+				(string, "<separator/><menuitem action=\"%s\" name=\"OpenTabs\"/>", name);
 		}
 	}
 }
