@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.147 2006/10/22 17:08:06 jframeau Exp $
+ *  $Id: ephy-shell.c,v 1.148 2006/11/12 21:03:41 jframeau Exp $
  */
 
 #include "config.h"
@@ -508,6 +508,15 @@ ephy_shell_new_tab_full (EphyShell *shell,
 
 	ephy_window_add_tab (window, tab, position, jump_to);
 
+	if (previous_embed != NULL)
+	{
+		ephy_embed_shistory_copy (previous_embed,
+					  embed,
+					  TRUE,   /* back history */
+					  TRUE,   /* forward history */
+					  FALSE); /* current index */
+	}
+
 	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
 
 	if ((flags & EPHY_NEW_TAB_DONT_SHOW_WINDOW) == 0)
@@ -572,15 +581,6 @@ ephy_shell_new_tab_full (EphyShell *shell,
                 }
         }
 
-	if (previous_embed != NULL)
-	{
-		ephy_embed_shistory_copy (previous_embed,
-					  embed,
-					  TRUE,   /* back history */
-					  FALSE,  /* forward history */
-					  FALSE); /* current index */
-	}
-
 	return tab;
 }
 
