@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003-2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +15,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: prefs-dialog.h,v 1.7 2006/09/13 11:34:23 chpe Exp $
  */
 
 #ifndef PREFS_DIALOG_H
@@ -24,20 +27,24 @@
 #include <glib-object.h>
 #include <glib.h>
 
-typedef struct PrefsDialog PrefsDialog;
-typedef struct PrefsDialogClass PrefsDialogClass;
+G_BEGIN_DECLS
 
-#define PREFS_DIALOG_TYPE             (prefs_dialog_get_type ())
-#define PREFS_DIALOG(obj)             (GTK_CHECK_CAST ((obj), PREFS_DIALOG_TYPE, PrefsDialog))
-#define PREFS_DIALOG_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), PREFS_DIALOG, PrefsDialogClass))
-#define IS_PREFS_DIALOG(obj)          (GTK_CHECK_TYPE ((obj), PREFS_DIALOG_TYPE))
-#define IS_PREFS_DIALOG_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), PREFS_DIALOG))
+#define EPHY_TYPE_PREFS_DIALOG		(prefs_dialog_get_type ())
+#define EPHY_PREFS_DIALOG(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_PREFS_DIALOG, PrefsDialog))
+#define EPHY_PREFS_DIALOG_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_PREFS_DIALOG, PrefsDialogClass))
+#define EPHY_IS_PREFS_DIALOG(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_PREFS_DIALOG))
+#define EPHY_IS_PREFS_DIALOG_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_PREFS_DIALOG))
+#define EPHY_PREFS_DIALOG_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_PREFS_DIALOG, PrefsDialogClass))
 
-typedef struct PrefsDialogPrivate PrefsDialogPrivate;
+typedef struct PrefsDialog		PrefsDialog;
+typedef struct PrefsDialogClass		PrefsDialogClass;
+typedef struct PrefsDialogPrivate	PrefsDialogPrivate;
 
 struct PrefsDialog
 {
         EphyDialog parent;
+
+	/*< private >*/
         PrefsDialogPrivate *priv;
 };
 
@@ -48,6 +55,6 @@ struct PrefsDialogClass
 
 GType         prefs_dialog_get_type           (void);
 
-EphyDialog   *prefs_dialog_new		      (GtkWidget *parent);
+G_END_DECLS
 
 #endif
