@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.h 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: window-commands.h,v 1.27 2006/09/24 19:59:37 jframeau Exp $
  */
 
 #include <gtk/gtkaction.h>
@@ -43,12 +43,6 @@ void window_cmd_view_reload	(GtkAction *action,
 void window_cmd_new		(GtkAction *action,
 				 EphyWindow *window);
 
-void window_cmd_file_new_window	(GtkAction *action,
-				 EphyWindow *window);
-
-void window_cmd_file_new_tab	(GtkAction *action,
-				 EphyWindow *window);
-
 void window_cmd_file_bookmark_page(GtkAction *action,
 				  EphyWindow *window);
 
